src/pyams_content/component/paragraph/zmi/html.py
changeset 406 5527bc086216
parent 403 992892d242a7
child 407 0ef5de2d5674
--- a/src/pyams_content/component/paragraph/zmi/html.py	Thu Feb 22 10:15:00 2018 +0100
+++ b/src/pyams_content/component/paragraph/zmi/html.py	Thu Feb 22 12:00:05 2018 +0100
@@ -20,7 +20,7 @@
 from pyams_content.component.association.zmi.interfaces import IAssociationsParentForm
 from pyams_content.component.illustration.interfaces import IIllustration
 from pyams_content.component.paragraph.interfaces import IParagraphContainerTarget, IParagraphContainer, \
-    IParagraphSummary
+    IParagraphPreview
 from pyams_content.component.paragraph.interfaces.html import IHTMLParagraph, IRawParagraph
 from pyams_content.component.paragraph.zmi.interfaces import IParagraphInnerEditor, IParagraphContainerView
 from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
@@ -146,13 +146,13 @@
 
 
 #
 # Raw HTML paragraph summary
 #
 
-@adapter_config(context=(IRawParagraph, IPyAMSLayer), provides=IParagraphSummary)
-@template_config(template='templates/raw-summary.pt', layer=IPyAMSLayer)
-class RawParagraphSummary(BaseContentProvider):
-    """Raw HTML paragraph summary"""
+@adapter_config(context=(IRawParagraph, IPyAMSLayer), provides=IParagraphPreview)
+@template_config(template='templates/raw-preview.pt', layer=IPyAMSLayer)
+class RawParagraphPreview(BaseContentProvider):
+    """Raw HTML paragraph preview"""
 
     language = None
 
@@ -330,13 +330,13 @@
 
 
 #
 # Rich text paragraph summary
 #
 
-@adapter_config(context=(IHTMLParagraph, IPyAMSLayer), provides=IParagraphSummary)
-@template_config(template='templates/html-summary.pt', layer=IPyAMSLayer)
-class HTMLParagraphSummary(BaseContentProvider):
-    """Rich text paragraph summary"""
+@adapter_config(context=(IHTMLParagraph, IPyAMSLayer), provides=IParagraphPreview)
+@template_config(template='templates/html-preview.pt', layer=IPyAMSLayer)
+class HTMLParagraphPreview(BaseContentProvider):
+    """Rich text paragraph preview"""
 
     illustration = None
     illustration_renderer = None
@@ -146,13 +146,13 @@
 
 #
-# Raw HTML paragraph summary
+# Raw HTML paragraph preview
 #
 
@@ -330,13 +330,13 @@
 
 #
-# Rich text paragraph summary
+# Rich text paragraph preview
 #
 